package VMOMI::HostFirewallRulesetIpList;
use parent 'VMOMI::DynamicData';

use strict;
use warnings;

our @class_ancestors = ( 
    'DynamicData',
);

our @class_members = ( 
    ['ipAddress', undef, 1, 1],
    ['ipNetwork', 'HostFirewallRulesetIpNetwork', 1, 1],
    ['allIp', 'boolean', 0, ],
);

sub get_class_ancestors {
    return @class_ancestors;
}

sub get_class_members {
    my $class = shift;
    my @super_members = $class->SUPER::get_class_members();
    return (@super_members, @class_members);
}

1;
